version

package
v1.4.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Copyright (c) Tobias Schäfer. All rights reserved. Licensed under the MIT license, see LICENSE in the project root for details.

Index

Constants

This section is empty.

Variables

var (
	GitCommit, Version string
)

Functions

func Banner() string

Banner returns the ASCII art banner of the application.

func Commit

func Commit() string

Commit returns the current git commit hash of the application.

func Print

func Print()

Print prints the colored banner, release version, and commit hash to the console. Coloring can be disabled by setting the NO_COLOR environment variable to "1" or "true".

func Release

func Release() string

Release returns the current version of the application.

Types

This section is empty.

Jump to