Documentation
¶
Overview ¶
Copyright (c) Tobias Schäfer. All rights reserved. Licensed under the MIT License, see LICENSE file in the project root for details.
Copyright (c) Tobias Schäfer. All rights reserved. Licensed under the MIT License, see LICENSE file in the project root for details.
Copyright (c) Tobias Schäfer. All rights reserved. Licensed under the MIT License, see LICENSE file in the project root for details.
Copyright (c) Tobias Schäfer. All rights reserved. Licensed under the MIT License, see LICENSE file in the project root for details.
Copyright (c) Tobias Schäfer. All rights reserved. Licensed under the MIT License, see LICENSE file in the project root for details.
Index ¶
Constants ¶
const (
ExitOnWarningEnv string = "CONNTRACKD_SINK_EXIT_ON_WARNING"
)
Variables ¶
var LokiProtocols = []string{"http", "https"}
Supported Loki protocols.
var StreamWriters = []string{"stdout", "stderr", "discard"}
Available stream writers
var SyslogProtocols = []string{"udp", "tcp", "unix", "unixgram", "unixpacket"}
SyslogProtocols lists the supported syslog protocols.
Functions ¶
This section is empty.
Types ¶
type Journal ¶
type Journal struct {
Enable bool
}
Journal represents a systemd journal logging sink.
func (*Journal) TargetJournal ¶
TargetJournal creates a sink target for systemd journal logging.
type Loki ¶
Loki represents Loki logging sink.
func (*Loki) TargetLoki ¶
TargetLoki creates a sink target for Loki.
type SinkTarget ¶
type SinkTarget func(*slog.HandlerOptions) (slog.Handler, error)
SinkTarget defines a function type for initializing a sink target.
type Stream ¶ added in v0.2.0
Stream represents a standard output stream sink.
func (*Stream) TargetStream ¶ added in v0.2.0
TargetStream creates a sink target for standard output streams.